<?php


namespace Controllers;


use Exception;
use Exception\CustomException;
use Traits\TResponse;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Services\PrivacyPolicy as PrivacyPolicyService;

class PrivacyPolicy extends Simple
{
    use TResponse;

    /** @var PrivacyPolicyService $privacyPolicyService */
    protected $privacyPolicyService;

    /**
     * PrivacyPolicy constructor.
     * @param PrivacyPolicyService $privacyPolicyService
     */
    public function __construct(PrivacyPolicyService $privacyPolicyService)
    {
        $this->privacyPolicyService = $privacyPolicyService;
    }

    public function uploadPrivacyPolicy(Request $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows()[0];
            $pdfPath = $rows['UPLOAD_PRIVACY_POLICY'][0]['path'];
            $data = $this->privacyPolicyService->uploadPrivacyPolicy($pdfPath);
            $this->sendResponse($data, 200);
        } catch(CustomException $e) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function removePrivacyPolicy(Request $request, Response $response)
    {
        try {
            $data = $this->privacyPolicyService->removePrivacyPolicy();
            $response->addDataSet(new DataSet ('removePrivacyPolicy', $data));
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    public function findPrivacyPolicy(Request $request, Response $response)
    {
        try {
            $data = $this->privacyPolicyService->findPrivacyPolicy();
            $response->addDataSet(new DataSet ('findPrivacyPolicy', $data));
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws Exception
     */
    public function findPrivacyPolicyByAuthentication(Request $request, Response $response)
    {
        try {
            $user = $request->getParameters()['user'] ?? null;
            $data = $this->privacyPolicyService->findPrivacyPolicyByAuthentication($user);
            $this->sendResponse($data, 200);
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }
}
