import { Modal, ModalService, DialogService } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { FileUpload } from '@/services/FileUpload';
import { LoginDialogService } from '@/services/LoginDialogService';
import { LoginAlertService } from '@/services/LoginAlertService';
import Messages from '@/services/Messages';

export class PrivacyPolicyController {
    private modalPrivacyPolicy!: Modal;

    private doomIframe: any;

    private docSrc = '';

    private noFileSelected = true;

    private saveLoadingModal = false;

    public deleteModalLocker = false;

    public denieDeleteButton = true;

    public async createModalPrivacyPolicy() {
        try {
            const getPrivacyPolicy = await Http.get('/findPrivacyPolicy');
            this.docSrc = getPrivacyPolicy.data.dataset.findPrivacyPolicy[0].pdfPath;
            this.denieDeleteButton = getPrivacyPolicy.data.dataset.findPrivacyPolicy[0].documentDefault;
            this.modalPrivacyPolicy = await ModalService.createFromJson('pages/politicaPrivacidadeModal/politicaPrivacidadeModal', true);
            this.setDocSrc();
        } catch (e) {
            LoginDialogService.showErrorBackend(e);
        }
    }

    public setDocSrc() {
        const doomIframe = document.getElementById('iframeDocId') as HTMLIFrameElement;
        doomIframe.src = this.docSrc;
    }

    public destroyModalPrivacyPolicy() {
        this.modalPrivacyPolicy.destroy();
    }

    public openModalPrivacyPolicy() {
        this.modalPrivacyPolicy.show();
    }

    public closeModalPrivacyPolicy() {
        this.modalPrivacyPolicy.hide();
        this.noFileSelected = true;
    }

    public async deleteCurrentFile() {
        this.deleteModalLocker = false;
        DialogService.show({
            name: 'delete_dialog',
            type: 'error',
            title: 'Excluir Política de Privacidade',
            text: Messages.DELETE_DEFAULT,
            buttons: [
                { name: 'yesBtn', component: 'ZdButton', label: 'Sim', events: this.dialogContinue, outline: true },
                { name: 'noBtn', component: 'ZdButton', label: 'Não', events: this.dialogHide },
            ],
        });
    }

    private dialogContinue: any = {
        click: async () => {
            if (!this.deleteModalLocker) {
                this.deleteModalLocker = true;
                try {
                    const aux = await Http.delete('/removePrivacyPolicy');
                    LoginAlertService.defaultDeleteSuccessAlert();
                    this.docSrc = aux.data.dataset.removePrivacyPolicy[0].pdfPath;
                    await this.setDocSrc();
                    await DialogService.hide();
                    this.denieDeleteButton = true;
                } catch (e) {
                    LoginDialogService.showErrorBackend(e);
                    this.deleteModalLocker = false;
                }
            }
        },
    };

    private dialogHide: any = {
        click: () => DialogService.hide(),
    };

    public changeFileInput(params: any) {
        if (params.component.value.length > 0) {
            this.noFileSelected = false;
        } else {
            this.noFileSelected = true;
        }
    }

    public async saveModalPrivacyPolicy() {
        this.saveLoadingModal = true;
        this.noFileSelected = true;
        const fileInput: any = Metadata.getInstance('fileInputModalPrivacyPolicy');
        const sendObject = await FileUpload.buildFileSendObject(fileInput.value[0]);
        if (fileInput.value[0].type === 'application/pdf' && fileInput.value[0].size < 50000000) {
            try {
                const newDocSrc = await Http.post('/uploadPrivacyPolicy/save', {
                    dataset: [
                        {
                            UPLOAD_PRIVACY_POLICY:
                            [
                                sendObject,
                            ],
                        },
                    ],
                    requestType: 'DataSet',
                });
                this.docSrc = newDocSrc.data[0].pdfPath;
                await this.setDocSrc();
                this.denieDeleteButton = newDocSrc.data[0].documentDefault;
                this.modalPrivacyPolicy.hide();
            } catch (e) {
                LoginDialogService.showErrorBackend(e);
                this.noFileSelected = false;
            }
            LoginAlertService.defaultSaveSuccessAlert();
            this.saveLoadingModal = false;
        } else {
            LoginAlertService.customErrorAlert(Messages.ERROR_PDF);
            this.saveLoadingModal = false;
            this.noFileSelected = false;
        }
    }
}
